bayespy.inference.vmp.nodes.gaussian.GaussianGammaISODistribution.compute_message_to_parent
===========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISODistribution.compute_message_to_parent